==> 1.0.4.tar.gz: lib/admost_native_ad.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'admost_ad_events.dart';
import 'admost_banner_controller.dart';
import 'admost_banner_size.dart';

class AdmostNativeAd extends StatefulWidget {
  final String adUnitId;
  final AdmostBannerSize adSize;
  final String xibNameForIOS;
  final void Function(AdmostAdEvent, Map<String, dynamic>) listener;
  final void Function(AdmostBannerController) onNativeAdCreated;

  AdmostNativeAd({
    Key key,
    @required this.adUnitId,
    @required this.adSize,
    this.listener,
    this.onNativeAdCreated,
    this.xibNameForIOS,
  }) : super(key: key);

  @override
  _AdmostNativeAdState createState() => _AdmostNativeAdState();
}

class _AdmostNativeAdState extends State<AdmostNativeAd> {
  AdmostBannerController _controller;

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    final String viewType = 'admost_flutter/banner';

    if (defaultTargetPlatform == TargetPlatform.android) {
      // Pass parameters to the platform side.
      final Map<String, dynamic> creationParamsAndroid = <String, dynamic>{
        'adUnitId': widget.adUnitId,
        'isNativeAd': 'true'
      };

      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: AndroidView(
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: creationParamsAndroid,
          creationParamsCodec: const StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      // Pass parameters to the platform side.
      final Map<String, dynamic> creationParamsIOS = <String, dynamic>{
        'adUnitId': widget.adUnitId,
        'adSize': widget.adSize.toMap,
        'xibName': widget.xibNameForIOS,
        'isNativeAd': 'true'
      };

      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: UiKitView(
          viewType: viewType,
          creationParams: creationParamsIOS,
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else {
      return Text('$defaultTargetPlatform is not yet supported by the plugin');
    }
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdmostBannerController(id, widget.listener);

    if (widget.onNativeAdCreated != null) {
      widget.onNativeAdCreated(_controller);
    }
  }
}

==> 1.0.9.tar.gz: lib/admost_native_ad.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'admost_ad_events.dart';
import 'admost_banner_controller.dart';
import 'admost_banner_size.dart';

class AdmostNativeAd extends StatefulWidget {
  final String adUnitId;
  final AdmostBannerSize adSize;
  final String xibNameForIOS;
  final void Function(AdmostAdEvent, Map<String, dynamic>) listener;
  final void Function(AdmostBannerController) onNativeAdCreated;

  AdmostNativeAd({
    Key key,
    @required this.adUnitId,
    @required this.adSize,
    this.listener,
    this.onNativeAdCreated,
    this.xibNameForIOS,
  }) : super(key: key) {
    if(adUnitId == null || adSize == null) {
      print("adUnitId or adSize cannot be null!");
    }
  }

  @override
  _AdmostNativeAdState createState() => _AdmostNativeAdState();
}

class _AdmostNativeAdState extends State<AdmostNativeAd> {
  AdmostBannerController _controller;

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    final String viewType = 'admost_flutter/banner';

    if (defaultTargetPlatform == TargetPlatform.android) {
      // Pass parameters to the platform side.
      final Map<String, dynamic> creationParamsAndroid = <String, dynamic>{
        'adUnitId': widget.adUnitId,
        'isNativeAd': 'true'
      };

      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: AndroidView(
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: creationParamsAndroid,
          creationParamsCodec: const StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      // Pass parameters to the platform side.
      final Map<String, dynamic> creationParamsIOS = <String, dynamic>{
        'adUnitId': widget.adUnitId,
        'adSize': widget.adSize.toMap,
        'xibName': widget.xibNameForIOS,
        'isNativeAd': 'true'
      };

      return Container(
        width: widget.adSize.width >= 0
            ? widget.adSize.width.toDouble()
            : double.infinity,
        height: widget.adSize.height >= 0
            ? widget.adSize.height.toDouble()
            : double.infinity,
        child: UiKitView(
          viewType: viewType,
          creationParams: creationParamsIOS,
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    } else {
      return Text('$defaultTargetPlatform is not yet supported by the plugin');
    }
  }

  void _onPlatformViewCreated(int id) {
    _controller = AdmostBannerController(id, widget.listener);

    if (widget.onNativeAdCreated != null) {
      widget.onNativeAdCreated(_controller);
    }
  }
}
